<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Lekhak Pro
 * @since Lekhak Pro 1.0.0
 * @return array An array of default values
 */

function lekhak_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$lekhak_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2a2e43',
		'header_tagline_color'			=> '#2a2e43',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'menu_sticky_pick'				=> 'primary-menu-sticky',
		'primary_menu_label'           	=> esc_html__( 'Primary', 'lekhak-pro' ),
		'secondary_menu_label'          => esc_html__( 'Secondary', 'lekhak-pro' ),

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'lekhak-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'lekhak-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'lekhak-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'lekhak-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'lekhak-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */


		// Featured slider
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'page',
		'featured_count'				=> 3,
		'featured_btn_label'			=> esc_html__( 'Start Reading', 'lekhak-pro' ),

		// Featured post
		'featured_post_title'			=> esc_html__( 'Featured Posts', 'lekhak-pro' ),
		'featured_post_section_enable'	=> true,
		'featured_post_content_type'	=> 'post',
		'featured_post_count'			=> 3,

		// Popular post
		'popular_post_title'			=> esc_html__( 'Popular Posts', 'lekhak-pro' ),
		'popular_post_section_enable'	=> true,
		'popular_post_count'			=> 3,
		'popular_post_left_content_type'	=> 'post',
		'popular_post_right_content_type'	=> 'post',


		// blog
		'blog_section_title'			=> esc_html__( 'Latest Posts', 'lekhak-pro' ),
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 4,
		'blog_section_btn_label'		=> esc_html__( 'Read More', 'lekhak-pro' ),


	);

	$output = apply_filters( 'lekhak_pro_default_theme_options', $lekhak_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}