<?php
/**
 * Featured post Section options
 *
 * @package Theme Palace
 * @subpackage Lekhak Pro
 * @since Lekhak Pro 1.0.0
 */

// Add Featured post section
$wp_customize->add_section( 'lekhak_pro_featured_post_section', array(
	'title'             => esc_html__( 'Featured Posts','lekhak-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'lekhak-pro' ),
	'panel'             => 'lekhak_pro_front_page_panel',
) );

// Featured post content enable control and setting
$wp_customize->add_setting( 'lekhak_pro_theme_options[featured_post_section_enable]', array(
	'default'			=> 	$options['featured_post_section_enable'],
	'sanitize_callback' => 'lekhak_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Lekhak_Pro_Switch_Control( $wp_customize, 'lekhak_pro_theme_options[featured_post_section_enable]', array(
	'label'             => esc_html__( 'Featured posts Section Enable', 'lekhak-pro' ),
	'section'           => 'lekhak_pro_featured_post_section',
	'on_off_label' 		=> lekhak_pro_switch_options(),
) ) );

// Featured post content 
$wp_customize->add_setting( 'lekhak_pro_theme_options[featured_post_title]',
	array(
		'default'       	=> $options['featured_post_title'],
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport'			=> 'postMessage',
	)
);
$wp_customize->add_control( 'lekhak_pro_theme_options[featured_post_title]',
    array(
		'label'      		=> esc_html__( 'Featured Posts Title', 'lekhak-pro' ),
		'section'    		=> 'lekhak_pro_featured_post_section',
		'type'		 		=> 'text',
		'active_callback'   => 'lekhak_pro_is_featured_post_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'lekhak_pro_theme_options[featured_post_title]', array(
		'selector'            => '#featured-posts .section-header h2.section-title',
		'settings'            => 'lekhak_pro_theme_options[featured_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'lekhak_pro_featured_post_title_partial',
    ) );
}

// Featured post count control and setting
$wp_customize->add_setting( 'lekhak_pro_theme_options[featured_post_count]', array(
	'default'          	=> $options['featured_post_count'],
	'sanitize_callback' => 'lekhak_pro_sanitize_number_range',
	'validate_callback' => 'lekhak_pro_validate_featured_post_count',
) );

$wp_customize->add_control( 'lekhak_pro_theme_options[featured_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'lekhak-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'lekhak-pro' ),
	'section'           => 'lekhak_pro_featured_post_section',
	'active_callback'   => 'lekhak_pro_is_featured_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

// Featured post content type control and setting
$wp_customize->add_setting( 'lekhak_pro_theme_options[featured_post_content_type]', array(
	'default'          	=> $options['featured_post_content_type'],
	'sanitize_callback' => 'lekhak_pro_sanitize_select',
) );

$wp_customize->add_control( 'lekhak_pro_theme_options[featured_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'lekhak-pro' ),
	'section'           => 'lekhak_pro_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'lekhak_pro_is_featured_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'lekhak-pro' ),
		'post' 		=> esc_html__( 'Post', 'lekhak-pro' ),
		'category' 	=> esc_html__( 'Category', 'lekhak-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_post_count']; $i++ ) {
	// featured_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'lekhak_pro_theme_options[featured_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'lekhak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Lekhak_Pro_Dropdown_Chooser( $wp_customize, 'lekhak_pro_theme_options[featured_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'lekhak-pro' ), $i ),
		'section'           => 'lekhak_pro_featured_post_section',
		'choices'			=> lekhak_pro_page_choices(),
		'active_callback'	=> 'lekhak_pro_is_featured_post_section_content_page_enable',
	) ) );

	// featured_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'lekhak_pro_theme_options[featured_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'lekhak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Lekhak_Pro_Dropdown_Chooser( $wp_customize, 'lekhak_pro_theme_options[featured_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'lekhak-pro' ), $i ),
		'section'           => 'lekhak_pro_featured_post_section',
		'choices'			=> lekhak_pro_post_choices(),
		'active_callback'	=> 'lekhak_pro_is_featured_post_section_content_post_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'lekhak_pro_theme_options[featured_post_content_category]', array(
	'sanitize_callback' => 'lekhak_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Lekhak_Pro_Dropdown_Taxonomies_Control( $wp_customize,'lekhak_pro_theme_options[featured_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'lekhak-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'lekhak-pro' ),
	'section'           => 'lekhak_pro_featured_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'lekhak_pro_is_featured_post_section_content_category_enable'
) ) );