<?php
/**
 * Featured post section
 *
 * This is the template for the content of featured_post section
 *
 * @package Theme Palace
 * @subpackage Lekhak Pro
 * @since Lekhak Pro 1.0.0
 */
if ( ! function_exists( 'lekhak_pro_add_featured_post_section' ) ) :
    /**
    * Add featured_post section
    *
    *@since Lekhak Pro 1.0.0
    */
    function lekhak_pro_add_featured_post_section() {
    	$options = lekhak_pro_get_theme_options();
        // Check if featured_post is enabled on frontpage
        $featured_post_enable = apply_filters( 'lekhak_pro_section_status', true, 'featured_post_section_enable' );

        if ( true !== $featured_post_enable ) {
            return false;
        }
        // Get featured_post section details
        $section_details = array();
        $section_details = apply_filters( 'lekhak_pro_filter_featured_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_post section now.
        lekhak_pro_render_featured_post_section( $section_details );
    }
endif;
add_action( 'lekhak_pro_primary_content', 'lekhak_pro_add_featured_post_section', 20 );

if ( ! function_exists( 'lekhak_pro_get_featured_post_section_details' ) ) :
    /**
    * featured_post section details.
    *
    * @since Lekhak Pro 1.0.0
    * @param array $input featured_post section details.
    */
    function lekhak_pro_get_featured_post_section_details( $input ) {
        $options = lekhak_pro_get_theme_options();

        // Content type.
        $featured_post_content_type  = $options['featured_post_content_type'];
        $featured_post_count = ! empty( $options['featured_post_count'] ) ? $options['featured_post_count'] : 3;
        
        $content = array();
        switch ( $featured_post_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_post_count; $i++ ) {
                    if ( ! empty( $options['featured_post_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_post_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_post_count ),
                    'orderby'           => 'post__in',
                    );                     
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_post_count; $i++ ) {
                    if ( ! empty( $options['featured_post_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );   
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_post_content_category'] ) ? $options['featured_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = lekhak_pro_trim_content( 25 );
                $page_post['author_id'] = get_the_author_meta( 'ID' );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_post section content details.
add_filter( 'lekhak_pro_filter_featured_post_section_details', 'lekhak_pro_get_featured_post_section_details' );


if ( ! function_exists( 'lekhak_pro_render_featured_post_section' ) ) :
  /**
   * Start featured_post section
   *
   * @return string featured_post content
   * @since Lekhak Pro 1.0.0
   *
   */
   function lekhak_pro_render_featured_post_section( $content_details = array() ) {
        $options = lekhak_pro_get_theme_options();
        $featured_post_content_type  = $options['featured_post_content_type'];
        $featured_post_title  = ! empty( $options['featured_post_title'] ) ? $options['featured_post_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        $column = ( count( $content_details ) >= 3 ) ? 3 : count( $content_details );
        ?>
        <div id="featured-posts" class="relative page-section">
            <div class="wrapper">
                <?php if ( ! empty( $featured_post_title ) ) : ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $featured_post_title ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content col-<?php echo absint( $column );?>"><!-- supports col-1,col-2,col-3 -->
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-post-thumbnail'; ?>">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( 'page' !== $featured_post_content_type ) : ?>
                                    <div class="entry-meta">
                                        <?php lekhak_pro_article_categories_meta( $content['id'] ); ?>
                                    </div><!-- .entry-meta -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php  
                                        lekhak_pro_posted_on( $content['id'] );
                                        echo lekhak_pro_author( $content['author_id'] );
                                    ?>
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #fetaured-posts -->
    <?php 
    }
endif;